# coding: utf-8

"""
    Amun API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.5.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class InspectionStatusResponseBuild(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'container': 'str',
        'exit_code': 'int',
        'finished_at': 'str',
        'reason': 'str',
        'started_at': 'str',
        'state': 'str'
    }

    attribute_map = {
        'container': 'container',
        'exit_code': 'exit_code',
        'finished_at': 'finished_at',
        'reason': 'reason',
        'started_at': 'started_at',
        'state': 'state'
    }

    def __init__(self, container=None, exit_code=None, finished_at=None, reason=None, started_at=None, state=None):  # noqa: E501
        """InspectionStatusResponseBuild - a model defined in OpenAPI"""  # noqa: E501

        self._container = None
        self._exit_code = None
        self._finished_at = None
        self._reason = None
        self._started_at = None
        self._state = None
        self.discriminator = None

        self.container = container
        self.exit_code = exit_code
        self.finished_at = finished_at
        self.reason = reason
        self.started_at = started_at
        self.state = state

    @property
    def container(self):
        """Gets the container of this InspectionStatusResponseBuild.  # noqa: E501

        SHA of container image in which the inspection is done.  # noqa: E501

        :return: The container of this InspectionStatusResponseBuild.  # noqa: E501
        :rtype: str
        """
        return self._container

    @container.setter
    def container(self, container):
        """Sets the container of this InspectionStatusResponseBuild.

        SHA of container image in which the inspection is done.  # noqa: E501

        :param container: The container of this InspectionStatusResponseBuild.  # noqa: E501
        :type: str
        """

        self._container = container

    @property
    def exit_code(self):
        """Gets the exit_code of this InspectionStatusResponseBuild.  # noqa: E501

        Return code of the process perfoming inspection (user supplied script return value).   # noqa: E501

        :return: The exit_code of this InspectionStatusResponseBuild.  # noqa: E501
        :rtype: int
        """
        return self._exit_code

    @exit_code.setter
    def exit_code(self, exit_code):
        """Sets the exit_code of this InspectionStatusResponseBuild.

        Return code of the process perfoming inspection (user supplied script return value).   # noqa: E501

        :param exit_code: The exit_code of this InspectionStatusResponseBuild.  # noqa: E501
        :type: int
        """

        self._exit_code = exit_code

    @property
    def finished_at(self):
        """Gets the finished_at of this InspectionStatusResponseBuild.  # noqa: E501

        Datetime in ISO format informing about when the inspection has finished.   # noqa: E501

        :return: The finished_at of this InspectionStatusResponseBuild.  # noqa: E501
        :rtype: str
        """
        return self._finished_at

    @finished_at.setter
    def finished_at(self, finished_at):
        """Sets the finished_at of this InspectionStatusResponseBuild.

        Datetime in ISO format informing about when the inspection has finished.   # noqa: E501

        :param finished_at: The finished_at of this InspectionStatusResponseBuild.  # noqa: E501
        :type: str
        """

        self._finished_at = finished_at

    @property
    def reason(self):
        """Gets the reason of this InspectionStatusResponseBuild.  # noqa: E501

        Reasoning on finished inspection run.  # noqa: E501

        :return: The reason of this InspectionStatusResponseBuild.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this InspectionStatusResponseBuild.

        Reasoning on finished inspection run.  # noqa: E501

        :param reason: The reason of this InspectionStatusResponseBuild.  # noqa: E501
        :type: str
        """

        self._reason = reason

    @property
    def started_at(self):
        """Gets the started_at of this InspectionStatusResponseBuild.  # noqa: E501

        Datetime in ISO format informing about when the inspection has started.   # noqa: E501

        :return: The started_at of this InspectionStatusResponseBuild.  # noqa: E501
        :rtype: str
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this InspectionStatusResponseBuild.

        Datetime in ISO format informing about when the inspection has started.   # noqa: E501

        :param started_at: The started_at of this InspectionStatusResponseBuild.  # noqa: E501
        :type: str
        """
        if started_at is None:
            raise ValueError("Invalid value for `started_at`, must not be `None`")  # noqa: E501

        self._started_at = started_at

    @property
    def state(self):
        """Gets the state of this InspectionStatusResponseBuild.  # noqa: E501


        :return: The state of this InspectionStatusResponseBuild.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InspectionStatusResponseBuild.


        :param state: The state of this InspectionStatusResponseBuild.  # noqa: E501
        :type: str
        """
        if state is None:
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501

        self._state = state

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InspectionStatusResponseBuild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Amun API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.5.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class InspectionJobLogResponseLogOsRelease(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ansi_color': 'str',
        'bug_report_url': 'str',
        'cpe_name': 'str',
        'documentation_url': 'str',
        'home_url': 'str',
        'id': 'str',
        'logo': 'str',
        'name': 'str',
        'platform_id': 'str',
        'pretty_name': 'str',
        'privacy_policy_url': 'str',
        'redhat_bugzilla_product': 'str',
        'redhat_bugzilla_product_version': 'str',
        'redhat_support_product': 'str',
        'redhat_support_product_version': 'str',
        'support_url': 'str',
        'variant': 'str',
        'variant_id': 'str',
        'version': 'str',
        'version_codename': 'str',
        'version_id': 'str'
    }

    attribute_map = {
        'ansi_color': 'ansi_color',
        'bug_report_url': 'bug_report_url',
        'cpe_name': 'cpe_name',
        'documentation_url': 'documentation_url',
        'home_url': 'home_url',
        'id': 'id',
        'logo': 'logo',
        'name': 'name',
        'platform_id': 'platform_id',
        'pretty_name': 'pretty_name',
        'privacy_policy_url': 'privacy_policy_url',
        'redhat_bugzilla_product': 'redhat_bugzilla_product',
        'redhat_bugzilla_product_version': 'redhat_bugzilla_product_version',
        'redhat_support_product': 'redhat_support_product',
        'redhat_support_product_version': 'redhat_support_product_version',
        'support_url': 'support_url',
        'variant': 'variant',
        'variant_id': 'variant_id',
        'version': 'version',
        'version_codename': 'version_codename',
        'version_id': 'version_id'
    }

    def __init__(self, ansi_color=None, bug_report_url=None, cpe_name=None, documentation_url=None, home_url=None, id=None, logo=None, name=None, platform_id=None, pretty_name=None, privacy_policy_url=None, redhat_bugzilla_product=None, redhat_bugzilla_product_version=None, redhat_support_product=None, redhat_support_product_version=None, support_url=None, variant=None, variant_id=None, version=None, version_codename=None, version_id=None):  # noqa: E501
        """InspectionJobLogResponseLogOsRelease - a model defined in OpenAPI"""  # noqa: E501

        self._ansi_color = None
        self._bug_report_url = None
        self._cpe_name = None
        self._documentation_url = None
        self._home_url = None
        self._id = None
        self._logo = None
        self._name = None
        self._platform_id = None
        self._pretty_name = None
        self._privacy_policy_url = None
        self._redhat_bugzilla_product = None
        self._redhat_bugzilla_product_version = None
        self._redhat_support_product = None
        self._redhat_support_product_version = None
        self._support_url = None
        self._variant = None
        self._variant_id = None
        self._version = None
        self._version_codename = None
        self._version_id = None
        self.discriminator = None

        if ansi_color is not None:
            self.ansi_color = ansi_color
        if bug_report_url is not None:
            self.bug_report_url = bug_report_url
        if cpe_name is not None:
            self.cpe_name = cpe_name
        if documentation_url is not None:
            self.documentation_url = documentation_url
        if home_url is not None:
            self.home_url = home_url
        if id is not None:
            self.id = id
        if logo is not None:
            self.logo = logo
        if name is not None:
            self.name = name
        if platform_id is not None:
            self.platform_id = platform_id
        if pretty_name is not None:
            self.pretty_name = pretty_name
        if privacy_policy_url is not None:
            self.privacy_policy_url = privacy_policy_url
        if redhat_bugzilla_product is not None:
            self.redhat_bugzilla_product = redhat_bugzilla_product
        if redhat_bugzilla_product_version is not None:
            self.redhat_bugzilla_product_version = redhat_bugzilla_product_version
        if redhat_support_product is not None:
            self.redhat_support_product = redhat_support_product
        if redhat_support_product_version is not None:
            self.redhat_support_product_version = redhat_support_product_version
        if support_url is not None:
            self.support_url = support_url
        if variant is not None:
            self.variant = variant
        if variant_id is not None:
            self.variant_id = variant_id
        if version is not None:
            self.version = version
        if version_codename is not None:
            self.version_codename = version_codename
        if version_id is not None:
            self.version_id = version_id

    @property
    def ansi_color(self):
        """Gets the ansi_color of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The ansi_color of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._ansi_color

    @ansi_color.setter
    def ansi_color(self, ansi_color):
        """Sets the ansi_color of this InspectionJobLogResponseLogOsRelease.


        :param ansi_color: The ansi_color of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._ansi_color = ansi_color

    @property
    def bug_report_url(self):
        """Gets the bug_report_url of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The bug_report_url of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._bug_report_url

    @bug_report_url.setter
    def bug_report_url(self, bug_report_url):
        """Sets the bug_report_url of this InspectionJobLogResponseLogOsRelease.


        :param bug_report_url: The bug_report_url of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._bug_report_url = bug_report_url

    @property
    def cpe_name(self):
        """Gets the cpe_name of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The cpe_name of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._cpe_name

    @cpe_name.setter
    def cpe_name(self, cpe_name):
        """Sets the cpe_name of this InspectionJobLogResponseLogOsRelease.


        :param cpe_name: The cpe_name of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._cpe_name = cpe_name

    @property
    def documentation_url(self):
        """Gets the documentation_url of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The documentation_url of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._documentation_url

    @documentation_url.setter
    def documentation_url(self, documentation_url):
        """Sets the documentation_url of this InspectionJobLogResponseLogOsRelease.


        :param documentation_url: The documentation_url of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._documentation_url = documentation_url

    @property
    def home_url(self):
        """Gets the home_url of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The home_url of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._home_url

    @home_url.setter
    def home_url(self, home_url):
        """Sets the home_url of this InspectionJobLogResponseLogOsRelease.


        :param home_url: The home_url of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._home_url = home_url

    @property
    def id(self):
        """Gets the id of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The id of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InspectionJobLogResponseLogOsRelease.


        :param id: The id of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def logo(self):
        """Gets the logo of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The logo of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._logo

    @logo.setter
    def logo(self, logo):
        """Sets the logo of this InspectionJobLogResponseLogOsRelease.


        :param logo: The logo of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._logo = logo

    @property
    def name(self):
        """Gets the name of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The name of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InspectionJobLogResponseLogOsRelease.


        :param name: The name of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def platform_id(self):
        """Gets the platform_id of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The platform_id of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._platform_id

    @platform_id.setter
    def platform_id(self, platform_id):
        """Sets the platform_id of this InspectionJobLogResponseLogOsRelease.


        :param platform_id: The platform_id of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._platform_id = platform_id

    @property
    def pretty_name(self):
        """Gets the pretty_name of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The pretty_name of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._pretty_name

    @pretty_name.setter
    def pretty_name(self, pretty_name):
        """Sets the pretty_name of this InspectionJobLogResponseLogOsRelease.


        :param pretty_name: The pretty_name of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._pretty_name = pretty_name

    @property
    def privacy_policy_url(self):
        """Gets the privacy_policy_url of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The privacy_policy_url of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._privacy_policy_url

    @privacy_policy_url.setter
    def privacy_policy_url(self, privacy_policy_url):
        """Sets the privacy_policy_url of this InspectionJobLogResponseLogOsRelease.


        :param privacy_policy_url: The privacy_policy_url of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._privacy_policy_url = privacy_policy_url

    @property
    def redhat_bugzilla_product(self):
        """Gets the redhat_bugzilla_product of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The redhat_bugzilla_product of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._redhat_bugzilla_product

    @redhat_bugzilla_product.setter
    def redhat_bugzilla_product(self, redhat_bugzilla_product):
        """Sets the redhat_bugzilla_product of this InspectionJobLogResponseLogOsRelease.


        :param redhat_bugzilla_product: The redhat_bugzilla_product of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._redhat_bugzilla_product = redhat_bugzilla_product

    @property
    def redhat_bugzilla_product_version(self):
        """Gets the redhat_bugzilla_product_version of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The redhat_bugzilla_product_version of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._redhat_bugzilla_product_version

    @redhat_bugzilla_product_version.setter
    def redhat_bugzilla_product_version(self, redhat_bugzilla_product_version):
        """Sets the redhat_bugzilla_product_version of this InspectionJobLogResponseLogOsRelease.


        :param redhat_bugzilla_product_version: The redhat_bugzilla_product_version of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._redhat_bugzilla_product_version = redhat_bugzilla_product_version

    @property
    def redhat_support_product(self):
        """Gets the redhat_support_product of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The redhat_support_product of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._redhat_support_product

    @redhat_support_product.setter
    def redhat_support_product(self, redhat_support_product):
        """Sets the redhat_support_product of this InspectionJobLogResponseLogOsRelease.


        :param redhat_support_product: The redhat_support_product of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._redhat_support_product = redhat_support_product

    @property
    def redhat_support_product_version(self):
        """Gets the redhat_support_product_version of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The redhat_support_product_version of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._redhat_support_product_version

    @redhat_support_product_version.setter
    def redhat_support_product_version(self, redhat_support_product_version):
        """Sets the redhat_support_product_version of this InspectionJobLogResponseLogOsRelease.


        :param redhat_support_product_version: The redhat_support_product_version of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._redhat_support_product_version = redhat_support_product_version

    @property
    def support_url(self):
        """Gets the support_url of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The support_url of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._support_url

    @support_url.setter
    def support_url(self, support_url):
        """Sets the support_url of this InspectionJobLogResponseLogOsRelease.


        :param support_url: The support_url of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._support_url = support_url

    @property
    def variant(self):
        """Gets the variant of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The variant of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._variant

    @variant.setter
    def variant(self, variant):
        """Sets the variant of this InspectionJobLogResponseLogOsRelease.


        :param variant: The variant of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._variant = variant

    @property
    def variant_id(self):
        """Gets the variant_id of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The variant_id of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._variant_id

    @variant_id.setter
    def variant_id(self, variant_id):
        """Sets the variant_id of this InspectionJobLogResponseLogOsRelease.


        :param variant_id: The variant_id of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._variant_id = variant_id

    @property
    def version(self):
        """Gets the version of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The version of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InspectionJobLogResponseLogOsRelease.


        :param version: The version of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def version_codename(self):
        """Gets the version_codename of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The version_codename of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._version_codename

    @version_codename.setter
    def version_codename(self, version_codename):
        """Sets the version_codename of this InspectionJobLogResponseLogOsRelease.


        :param version_codename: The version_codename of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._version_codename = version_codename

    @property
    def version_id(self):
        """Gets the version_id of this InspectionJobLogResponseLogOsRelease.  # noqa: E501


        :return: The version_id of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this InspectionJobLogResponseLogOsRelease.


        :param version_id: The version_id of this InspectionJobLogResponseLogOsRelease.  # noqa: E501
        :type: str
        """

        self._version_id = version_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InspectionJobLogResponseLogOsRelease):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Amun API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.5.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class InspectionSpecificationRunRequestsHardware(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cpu_family': 'int',
        'cpu_model': 'int',
        'physical_cpus': 'int',
        'processor': 'str'
    }

    attribute_map = {
        'cpu_family': 'cpu_family',
        'cpu_model': 'cpu_model',
        'physical_cpus': 'physical_cpus',
        'processor': 'processor'
    }

    def __init__(self, cpu_family=None, cpu_model=None, physical_cpus=None, processor=None):  # noqa: E501
        """InspectionSpecificationRunRequestsHardware - a model defined in OpenAPI"""  # noqa: E501

        self._cpu_family = None
        self._cpu_model = None
        self._physical_cpus = None
        self._processor = None
        self.discriminator = None

        self.cpu_family = cpu_family
        self.cpu_model = cpu_model
        if physical_cpus is not None:
            self.physical_cpus = physical_cpus
        self.processor = processor

    @property
    def cpu_family(self):
        """Gets the cpu_family of this InspectionSpecificationRunRequestsHardware.  # noqa: E501

        CPU family number from CPU proc info.  # noqa: E501

        :return: The cpu_family of this InspectionSpecificationRunRequestsHardware.  # noqa: E501
        :rtype: int
        """
        return self._cpu_family

    @cpu_family.setter
    def cpu_family(self, cpu_family):
        """Sets the cpu_family of this InspectionSpecificationRunRequestsHardware.

        CPU family number from CPU proc info.  # noqa: E501

        :param cpu_family: The cpu_family of this InspectionSpecificationRunRequestsHardware.  # noqa: E501
        :type: int
        """
        if cpu_family is None:
            raise ValueError("Invalid value for `cpu_family`, must not be `None`")  # noqa: E501

        self._cpu_family = cpu_family

    @property
    def cpu_model(self):
        """Gets the cpu_model of this InspectionSpecificationRunRequestsHardware.  # noqa: E501

        Model number of CPU from CPU proc info.  # noqa: E501

        :return: The cpu_model of this InspectionSpecificationRunRequestsHardware.  # noqa: E501
        :rtype: int
        """
        return self._cpu_model

    @cpu_model.setter
    def cpu_model(self, cpu_model):
        """Sets the cpu_model of this InspectionSpecificationRunRequestsHardware.

        Model number of CPU from CPU proc info.  # noqa: E501

        :param cpu_model: The cpu_model of this InspectionSpecificationRunRequestsHardware.  # noqa: E501
        :type: int
        """
        if cpu_model is None:
            raise ValueError("Invalid value for `cpu_model`, must not be `None`")  # noqa: E501

        self._cpu_model = cpu_model

    @property
    def physical_cpus(self):
        """Gets the physical_cpus of this InspectionSpecificationRunRequestsHardware.  # noqa: E501

        Number of physical CPUs.  # noqa: E501

        :return: The physical_cpus of this InspectionSpecificationRunRequestsHardware.  # noqa: E501
        :rtype: int
        """
        return self._physical_cpus

    @physical_cpus.setter
    def physical_cpus(self, physical_cpus):
        """Sets the physical_cpus of this InspectionSpecificationRunRequestsHardware.

        Number of physical CPUs.  # noqa: E501

        :param physical_cpus: The physical_cpus of this InspectionSpecificationRunRequestsHardware.  # noqa: E501
        :type: int
        """

        self._physical_cpus = physical_cpus

    @property
    def processor(self):
        """Gets the processor of this InspectionSpecificationRunRequestsHardware.  # noqa: E501

        Name of the CPU model name of CPU proc info.  # noqa: E501

        :return: The processor of this InspectionSpecificationRunRequestsHardware.  # noqa: E501
        :rtype: str
        """
        return self._processor

    @processor.setter
    def processor(self, processor):
        """Sets the processor of this InspectionSpecificationRunRequestsHardware.

        Name of the CPU model name of CPU proc info.  # noqa: E501

        :param processor: The processor of this InspectionSpecificationRunRequestsHardware.  # noqa: E501
        :type: str
        """
        if processor is None:
            raise ValueError("Invalid value for `processor`, must not be `None`")  # noqa: E501

        self._processor = processor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InspectionSpecificationRunRequestsHardware):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Amun API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.5.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class InspectionSpecification(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'base': 'str',
        'update': 'bool',
        'packages': 'list[str]',
        'python_packages': 'list[str]',
        'python': 'InspectionSpecificationPython',
        'identifier': 'str',
        'build': 'InspectionSpecificationBuild',
        'run': 'InspectionSpecificationRun',
        'files': 'list[InspectionSpecificationFiles]',
        'environment': 'list[InspectionSpecificationEnvironment]',
        'script': 'str'
    }

    attribute_map = {
        'base': 'base',
        'update': 'update',
        'packages': 'packages',
        'python_packages': 'python_packages',
        'python': 'python',
        'identifier': 'identifier',
        'build': 'build',
        'run': 'run',
        'files': 'files',
        'environment': 'environment',
        'script': 'script'
    }

    def __init__(self, base=None, update=None, packages=None, python_packages=None, python=None, identifier=None, build=None, run=None, files=None, environment=None, script=None):  # noqa: E501
        """InspectionSpecification - a model defined in OpenAPI"""  # noqa: E501

        self._base = None
        self._update = None
        self._packages = None
        self._python_packages = None
        self._python = None
        self._identifier = None
        self._build = None
        self._run = None
        self._files = None
        self._environment = None
        self._script = None
        self.discriminator = None

        self.base = base
        if update is not None:
            self.update = update
        if packages is not None:
            self.packages = packages
        if python_packages is not None:
            self.python_packages = python_packages
        if python is not None:
            self.python = python
        if identifier is not None:
            self.identifier = identifier
        if build is not None:
            self.build = build
        if run is not None:
            self.run = run
        if files is not None:
            self.files = files
        if environment is not None:
            self.environment = environment
        if script is not None:
            self.script = script

    @property
    def base(self):
        """Gets the base of this InspectionSpecification.  # noqa: E501

        Base image on which the runtime environment should be based on.  # noqa: E501

        :return: The base of this InspectionSpecification.  # noqa: E501
        :rtype: str
        """
        return self._base

    @base.setter
    def base(self, base):
        """Sets the base of this InspectionSpecification.

        Base image on which the runtime environment should be based on.  # noqa: E501

        :param base: The base of this InspectionSpecification.  # noqa: E501
        :type: str
        """
        if base is None:
            raise ValueError("Invalid value for `base`, must not be `None`")  # noqa: E501
        if base is not None and len(base) < 1:
            raise ValueError("Invalid value for `base`, length must be greater than or equal to `1`")  # noqa: E501

        self._base = base

    @property
    def update(self):
        """Gets the update of this InspectionSpecification.  # noqa: E501

        Perform native packages update.  # noqa: E501

        :return: The update of this InspectionSpecification.  # noqa: E501
        :rtype: bool
        """
        return self._update

    @update.setter
    def update(self, update):
        """Sets the update of this InspectionSpecification.

        Perform native packages update.  # noqa: E501

        :param update: The update of this InspectionSpecification.  # noqa: E501
        :type: bool
        """

        self._update = update

    @property
    def packages(self):
        """Gets the packages of this InspectionSpecification.  # noqa: E501

        A list of native packages that should be installed into the runtime environment.  # noqa: E501

        :return: The packages of this InspectionSpecification.  # noqa: E501
        :rtype: list[str]
        """
        return self._packages

    @packages.setter
    def packages(self, packages):
        """Sets the packages of this InspectionSpecification.

        A list of native packages that should be installed into the runtime environment.  # noqa: E501

        :param packages: The packages of this InspectionSpecification.  # noqa: E501
        :type: list[str]
        """

        self._packages = packages

    @property
    def python_packages(self):
        """Gets the python_packages of this InspectionSpecification.  # noqa: E501

        A list of python packages that should be installed into the runtime environment.  # noqa: E501

        :return: The python_packages of this InspectionSpecification.  # noqa: E501
        :rtype: list[str]
        """
        return self._python_packages

    @python_packages.setter
    def python_packages(self, python_packages):
        """Sets the python_packages of this InspectionSpecification.

        A list of python packages that should be installed into the runtime environment.  # noqa: E501

        :param python_packages: The python_packages of this InspectionSpecification.  # noqa: E501
        :type: list[str]
        """

        self._python_packages = python_packages

    @property
    def python(self):
        """Gets the python of this InspectionSpecification.  # noqa: E501


        :return: The python of this InspectionSpecification.  # noqa: E501
        :rtype: InspectionSpecificationPython
        """
        return self._python

    @python.setter
    def python(self, python):
        """Sets the python of this InspectionSpecification.


        :param python: The python of this InspectionSpecification.  # noqa: E501
        :type: InspectionSpecificationPython
        """

        self._python = python

    @property
    def identifier(self):
        """Gets the identifier of this InspectionSpecification.  # noqa: E501

        A user-created string which will be inserted into the inspection id to distinguish different inspection runs.  # noqa: E501

        :return: The identifier of this InspectionSpecification.  # noqa: E501
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """Sets the identifier of this InspectionSpecification.

        A user-created string which will be inserted into the inspection id to distinguish different inspection runs.  # noqa: E501

        :param identifier: The identifier of this InspectionSpecification.  # noqa: E501
        :type: str
        """

        self._identifier = identifier

    @property
    def build(self):
        """Gets the build of this InspectionSpecification.  # noqa: E501


        :return: The build of this InspectionSpecification.  # noqa: E501
        :rtype: InspectionSpecificationBuild
        """
        return self._build

    @build.setter
    def build(self, build):
        """Sets the build of this InspectionSpecification.


        :param build: The build of this InspectionSpecification.  # noqa: E501
        :type: InspectionSpecificationBuild
        """

        self._build = build

    @property
    def run(self):
        """Gets the run of this InspectionSpecification.  # noqa: E501


        :return: The run of this InspectionSpecification.  # noqa: E501
        :rtype: InspectionSpecificationRun
        """
        return self._run

    @run.setter
    def run(self, run):
        """Sets the run of this InspectionSpecification.


        :param run: The run of this InspectionSpecification.  # noqa: E501
        :type: InspectionSpecificationRun
        """

        self._run = run

    @property
    def files(self):
        """Gets the files of this InspectionSpecification.  # noqa: E501

        Files passed to the context.  # noqa: E501

        :return: The files of this InspectionSpecification.  # noqa: E501
        :rtype: list[InspectionSpecificationFiles]
        """
        return self._files

    @files.setter
    def files(self, files):
        """Sets the files of this InspectionSpecification.

        Files passed to the context.  # noqa: E501

        :param files: The files of this InspectionSpecification.  # noqa: E501
        :type: list[InspectionSpecificationFiles]
        """

        self._files = files

    @property
    def environment(self):
        """Gets the environment of this InspectionSpecification.  # noqa: E501

        Environment variables supplied into the build process.  # noqa: E501

        :return: The environment of this InspectionSpecification.  # noqa: E501
        :rtype: list[InspectionSpecificationEnvironment]
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this InspectionSpecification.

        Environment variables supplied into the build process.  # noqa: E501

        :param environment: The environment of this InspectionSpecification.  # noqa: E501
        :type: list[InspectionSpecificationEnvironment]
        """

        self._environment = environment

    @property
    def script(self):
        """Gets the script of this InspectionSpecification.  # noqa: E501

        A script that should be executed in inspection run.  # noqa: E501

        :return: The script of this InspectionSpecification.  # noqa: E501
        :rtype: str
        """
        return self._script

    @script.setter
    def script(self, script):
        """Sets the script of this InspectionSpecification.

        A script that should be executed in inspection run.  # noqa: E501

        :param script: The script of this InspectionSpecification.  # noqa: E501
        :type: str
        """

        self._script = script

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InspectionSpecification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
